# Table of Contents

- [creating-your-first-diagram-and-adding-basic-elements](<./creating-your-first-diagram-and-adding-basic-elements.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Creating Diagrams and Adding Basic Elements](<./Creating-Diagrams-and-Adding-Basic-Elements.md>)
  - [Overview](<./Creating-Diagrams-and-Adding-Basic-Elements/Overview.md>)
  - [About the Diagram Editor](<./Creating-Diagrams-and-Adding-Basic-Elements/About-the-Diagram-Editor.md>)
  - [Step 1: Create Your First Diagram](<./Creating-Diagrams-and-Adding-Basic-Elements/Step-1-Create-Your-First-Diagram.md>)
  - [Step 2: Understand the Diagram Editor](<./Creating-Diagrams-and-Adding-Basic-Elements/Step-2-Understand-the-Diagram-Editor.md>)
  - [Step 3: Learn the Basic Diagram Elements](<./Creating-Diagrams-and-Adding-Basic-Elements/Step-3-Learn-the-Basic-Diagram-Elements.md>)
  - [Step 4: Add Shapes and Fact Sheets to Your Diagram](<./Creating-Diagrams-and-Adding-Basic-Elements/Step-4-Add-Shapes-and-Fact-Sheets-to-Your-Diagram.md>)
  - [Step 5: Connect Elements](<./Creating-Diagrams-and-Adding-Basic-Elements/Step-5-Connect-Elements.md>)
  - [Next Steps](<./Creating-Diagrams-and-Adding-Basic-Elements/Next-Steps.md>)
